@@ -12,18 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from tempfile import TemporaryDirectory
-from distutils.dir_util import copy_tree
-
 import logging
 import os
 from os.path import join
 from pathlib import Path
-
-from mkdocs.utils import warning_filter
+from shutil import copytree
+from tempfile import TemporaryDirectory
 
 log = logging.getLogger(__name__)
-log.addFilter(warning_filter)
 
 # This collects the multiple docs/ folders and merges them together.
 
@@ -31,23 +27,30 @@ log.addFilter(warning_filter)
 class Merger:
     def __init__(self, config):
         self.config = config
-        self.root_docs_dir = config['docs_dir']
+        self.root_docs_dir = config["docs_dir"]
         self.docs_dirs = list()
-        self.append('', self.root_docs_dir)
+        self.append("", self.root_docs_dir)
         self.files_source_dir = dict()
 
     def append(self, alias, docs_dir):
         self.docs_dirs.append([alias, docs_dir])
 
     def merge(self):
-        self.temp_docs_dir = TemporaryDirectory('', 'docs_')
+        self.temp_docs_dir = TemporaryDirectory("", "docs_")
 
-        aliases = list(filter(lambda docs_dir: len(docs_dir) > 0, map(
-            lambda docs_dir: docs_dir[0], self.docs_dirs)))
+        aliases = list(
+            filter(
+                lambda docs_dir: len(docs_dir) > 0,
+                map(lambda docs_dir: docs_dir[0], self.docs_dirs),
+            )
+        )
         if len(aliases) != len(set(aliases)):
             log.critical(
-                "[mkdocs-monorepo] You cannot have duplicated site names. " +
-                "Current registered site names in the monorepository: {}".format(', '.join(aliases)))
+                "[mkdocs-monorepo] You cannot have duplicated site names. "
+                + "Current registered site names in the monorepository: {}".format(
+                    ", ".join(aliases)
+                )
+            )
             raise SystemExit(1)
 
         for alias, docs_dir in self.docs_dirs:
@@ -59,8 +62,8 @@ class Merger:
                 dest_dir = os.path.join(self.temp_docs_dir.name, *split_alias)
 
             if os.path.exists(source_dir):
-                copy_tree(source_dir, dest_dir)
-                for file_abs_path in Path(source_dir).rglob('*.md'):
+                copytree(source_dir, dest_dir, symlinks=True, dirs_exist_ok=True)
+                for file_abs_path in Path(source_dir).rglob("*.md"):
                     file_abs_path = str(file_abs_path)  # python 3.5 compatibility
                     if os.path.isfile(file_abs_path):
                         file_rel_path = os.path.relpath(file_abs_path, source_dir)
@@ -69,8 +72,9 @@ class Merger:
 
             else:
                 log.critical(
-                    "[mkdocs-monorepo] The {} path is not valid. ".format(source_dir) +
-                    "Please update your 'nav' with a valid path.")
+                    "[mkdocs-monorepo] The {} path is not valid. ".format(source_dir)
+                    + "Please update your 'nav' with a valid path."
+                )
                 raise SystemExit(1)
 
         return str(self.temp_docs_dir.name)
