@@ -12,17 +12,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import copy
 import logging
 import os
-import copy
 import re
 from pathlib import Path
-
-from slugify import slugify
-from mkdocs.utils import yaml_load, warning_filter, dirname_to_title, get_markdown_title
 from urllib.parse import urlsplit
+
+from mkdocs.utils import dirname_to_title, get_markdown_title, yaml_load
+from slugify import slugify
+
 log = logging.getLogger(__name__)
-log.addFilter(warning_filter)
 
 INCLUDE_STATEMENT = "!include "
 WILDCARD_INCLUDE_STATEMENT = "*include "
@@ -30,7 +30,7 @@ WILDCARD_INCLUDE_STATEMENT = "*include "
 
 class Parser:
     def __init__(self, config):
-        self.initialNav = config['nav']
+        self.initialNav = config["nav"]
         self.config = config
 
     def __loadAliasesAndResolvedPaths(self, nav=None):
@@ -45,21 +45,23 @@ class Parser:
             elif type(item) is dict:
                 value = list(item.values())[0]
                 if type(value) is str and value.startswith(WILDCARD_INCLUDE_STATEMENT):
-                    root_dir = Path(self.config['config_file_path']).parent
-                    mkdocs_path = value[len(WILDCARD_INCLUDE_STATEMENT):]
+                    root_dir = Path(self.config["config_file_path"]).parent
+                    mkdocs_path = value[len(WILDCARD_INCLUDE_STATEMENT) :]
                     dirs = sorted(root_dir.glob(mkdocs_path))
                     if dirs:
                         value = []
                         for mkdocs_config in dirs:
                             site = {}
                             if os.path.exists(mkdocs_config):
-                                site[str(mkdocs_config)] = f"{INCLUDE_STATEMENT}{mkdocs_config.resolve()}"
+                                site[str(mkdocs_config)] = (
+                                    f"{INCLUDE_STATEMENT}{mkdocs_config.absolute()}"
+                                )
                                 value.append(site)
             else:
                 value = None
 
             if type(value) is str and value.startswith(INCLUDE_STATEMENT):
-                paths.append(value[len(INCLUDE_STATEMENT):])
+                paths.append(value[len(INCLUDE_STATEMENT) :])
             elif type(value) is list:
                 paths.extend(self.__loadAliasesAndResolvedPaths(value))
 
@@ -67,20 +69,25 @@ class Parser:
 
     def getResolvedPaths(self):
         """Return list of [alias, docs_dir, mkdocs.yml]."""
+
         def extractAliasAndPath(absPath):
             loader = IncludeNavLoader(self.config, absPath).read()
             alias = loader.getAlias()
-            docsDir = os.path.join(loader.rootDir, os.path.dirname(absPath), loader.getDocsDir())
+            docsDir = os.path.join(
+                loader.rootDir, os.path.dirname(absPath), loader.getDocsDir()
+            )
             return [alias, docsDir, os.path.join(loader.rootDir, absPath)]
 
         resolvedPaths = list(
-            map(extractAliasAndPath, self.__loadAliasesAndResolvedPaths()))
+            map(extractAliasAndPath, self.__loadAliasesAndResolvedPaths())
+        )
 
         for alias, docsDir, ymlPath in resolvedPaths:
             if not os.path.exists(docsDir):
                 log.critical(
-                    "[mkdocs-monorepo] The {} path is not valid. ".format(docsDir) +
-                    "Please update your 'nav' with a valid path.")
+                    "[mkdocs-monorepo] The {} path is not valid. ".format(docsDir)
+                    + "Please update your 'nav' with a valid path."
+                )
                 raise SystemExit(1)
 
         return resolvedPaths
@@ -97,12 +104,13 @@ class Parser:
                 key = list(item.keys())[0]
                 value = list(item.values())[0]
                 if type(value) is str and value.startswith(WILDCARD_INCLUDE_STATEMENT):
-                    root_dir = Path(self.config['config_file_path']).parent
-                    mkdocs_path = value[len(WILDCARD_INCLUDE_STATEMENT):]
+                    root_dir = Path(self.config["config_file_path"]).parent
+                    mkdocs_path = value[len(WILDCARD_INCLUDE_STATEMENT) :]
                     if not mkdocs_path.endswith(tuple([".yml", ".yaml"])):
                         log.critical(
                             "[mkdocs-monorepo] The wildcard include path {} does not end with .yml (or .yaml)".format(
-                                mkdocs_path)
+                                mkdocs_path
+                            )
                         )
                         raise SystemExit(1)
                     dirs = sorted(root_dir.glob(mkdocs_path))
@@ -111,18 +119,24 @@ class Parser:
                         for mkdocs_config in dirs:
                             site = {}
                             try:
-                                with open(mkdocs_config, 'rb') as f:
+                                with open(mkdocs_config, "rb") as f:
                                     site_yaml = yaml_load(f)
                                     site_name = site_yaml["site_name"]
-                                site[site_name] = f"{INCLUDE_STATEMENT}{mkdocs_config.resolve()}"
+                                site[site_name] = (
+                                    f"{INCLUDE_STATEMENT}{mkdocs_config.absolute()}"
+                                )
                                 value.append(site)
                             except OSError:
-                                log.error(f"[mkdocs-monorepo] The {mkdocs_config} path is not valid.")
+                                log.error(
+                                    f"[mkdocs-monorepo] The {mkdocs_config} path is not valid."
+                                )
                             except KeyError:
                                 log.critical(
-                                    "[mkdocs-monorepo] The file path {} does not contain a valid 'site_name' key ".format(mkdocs_config) +
-                                    "in the YAML file. Please include it to indicate where your documentation " +
-                                    "should be moved to."
+                                    "[mkdocs-monorepo] The file path {} does not contain a valid 'site_name' key ".format(
+                                        mkdocs_config
+                                    )
+                                    + "in the YAML file. Please include it to indicate where your documentation "
+                                    + "should be moved to."
                                 )
                                 raise SystemExit(1)
                         if not value:
@@ -135,10 +149,11 @@ class Parser:
 
             if type(value) is str and value.startswith(INCLUDE_STATEMENT):
                 nav[index] = {}
-                nav[index][key] = IncludeNavLoader(
-                    self.config,
-                    value[len(INCLUDE_STATEMENT):]
-                ).read().getNav()
+                nav[index][key] = (
+                    IncludeNavLoader(self.config, value[len(INCLUDE_STATEMENT) :])
+                    .read()
+                    .getNav()
+                )
 
                 if nav[index][key] is None:
                     return None
@@ -153,13 +168,18 @@ class Parser:
 
 
 class IncludeNavLoader:
-    def __init__(self, config, navPath):
-        self.rootDir = os.path.normpath(os.path.join(
-            os.getcwd(), config['config_file_path'], '../'))
+    def __init__(self, config, navPath, ancestors=None):
+        self.rootDir = os.path.normpath(
+            os.path.join(os.getcwd(), config["config_file_path"], "../")
+        )
         self.navPath = navPath
-        self.absNavPath = os.path.normpath(
-            os.path.join(self.rootDir, self.navPath))
+        self.absNavPath = os.path.normpath(os.path.join(self.rootDir, self.navPath))
         self.navYaml = None
+        # Track ancestor paths to detect cycles
+        if ancestors is None:
+            self.ancestors = set()
+        else:
+            self.ancestors = set(ancestors)
 
     def getAbsNavPath(self):
         return self.absNavPath
@@ -168,51 +188,53 @@ class IncludeNavLoader:
         if not self.absNavPath.endswith(tuple([".yml", ".yaml"])):
             log.critical(
                 "[mkdocs-monorepo] The included file path {} does not point to a .yml (or .yaml) file".format(
-                    self.absNavPath)
+                    self.absNavPath
+                )
             )
             raise SystemExit(1)
 
-        if not self.absNavPath.startswith(self.rootDir):
+        # Cycle detection: block self-references
+        if self.absNavPath in self.ancestors:
             log.critical(
-                "[mkdocs-monorepo] The mkdocs file {} is outside of the current directory. ".format(self.absNavPath) +
-                "Please move the file and try again."
+                f"[mkdocs-monorepo] Detected a self-reference or cycle when including {self.absNavPath}. "
+                f"Inclusion chain: {' -> '.join(self.ancestors)} -> {self.absNavPath}"
             )
             raise SystemExit(1)
 
+        # Add current file to ancestors for downstream includes
+        self.ancestors.add(self.absNavPath)
+
         try:
-            with open(self.absNavPath, 'rb') as f:
+            with open(self.absNavPath, "rb") as f:
                 self.navYaml = yaml_load(f)
 
             # This will check if there is a `docs_dir` property on the `mkdocs.yml` file of
             # the sub folder and scaffold the `nav` property from it
-            if self.navYaml and 'nav' not in self.navYaml:
+            if self.navYaml and "nav" not in self.navYaml:
                 docsDir = self.navYaml.get("docs_dir", "docs")
                 docsDirPath = os.path.join(os.path.dirname(self.absNavPath), docsDir)
 
                 def navFromDir(path):
                     directory = {}
-
                     for dirname, dirnames, filenames in os.walk(path):
-
                         dirnames.sort()
                         filenames.sort()
-
                         if dirname == docsDirPath:
                             dn = os.path.basename(dirname)
                         else:
                             dn = dirname_to_title(os.path.basename(dirname))
                         directory[dn] = []
-
                         for dirItem in dirnames:
                             subNav = navFromDir(path=os.path.join(path, dirItem))
                             if subNav:
                                 directory[dn].append(subNav)
-
                         for fileItem in filenames:
                             fileName, fileExt = os.path.splitext(fileItem)
-                            if fileExt == '.md':
+                            if fileExt == ".md":
                                 fileTitle = get_markdown_title(fileName)
-                                filePath = os.path.join(os.path.relpath(path, docsDirPath), fileItem)
+                                filePath = os.path.join(
+                                    os.path.relpath(path, docsDirPath), fileItem
+                                )
                                 directory[dn].append({fileTitle: filePath})
 
                         if len(directory[dn]) == 0 or directory[dn] == [{}]:
@@ -226,30 +248,36 @@ class IncludeNavLoader:
 
         except OSError:
             log.critical(
-                "[mkdocs-monorepo] The file path {} does not exist, ".format(self.absNavPath) +
-                "is not valid YAML, " +
-                "or does not contain a valid 'site_name' and 'nav' keys."
+                "[mkdocs-monorepo] The file path {} does not exist, ".format(
+                    self.absNavPath
+                )
+                + "is not valid YAML, "
+                + "or does not contain a valid 'site_name' and 'nav' keys."
             )
             raise SystemExit(1)
 
-        if self.navYaml and 'site_name' not in self.navYaml:
+        if self.navYaml and "site_name" not in self.navYaml:
             log.critical(
-                "[mkdocs-monorepo] The file path {} does not contain a valid 'site_name' key ".format(self.absNavPath) +
-                "in the YAML file. Please include it to indicate where your documentation " +
-                "should be moved to."
+                "[mkdocs-monorepo] The file path {} does not contain a valid 'site_name' key ".format(
+                    self.absNavPath
+                )
+                + "in the YAML file. Please include it to indicate where your documentation "
+                + "should be moved to."
             )
             raise SystemExit(1)
 
-        if self.navYaml and 'nav' not in self.navYaml:
+        if self.navYaml and "nav" not in self.navYaml:
             log.critical(
-                "[mkdocs-monorepo] The file path {} ".format(self.absNavPath) +
-                "does not contain a valid 'nav' key in the YAML file " +
-                "and the docs folder is not the default one, i.e. `docs`. " +
-                "Please include the `nav` key to indicate how your documentation should be presented in the navigation, " +
-                "or include a 'docs_dir' to indicate that automatic nav generation should be used."
+                "[mkdocs-monorepo] The file path {} ".format(self.absNavPath)
+                + "does not contain a valid 'nav' key in the YAML file "
+                + "and the docs folder is not the default one, i.e. `docs`. "
+                + "Please include the `nav` key to indicate how your documentation should be presented in the navigation, "
+                + "or include a 'docs_dir' to indicate that automatic nav generation should be used."
             )
             raise SystemExit(1)
 
+        # Remove current file from ancestors after processing (for sibling includes)
+        self.ancestors.remove(self.absNavPath)
         return self
 
     def getDocsDir(self):
@@ -257,7 +285,7 @@ class IncludeNavLoader:
 
     def getAlias(self):
         alias = self.navYaml["site_name"]
-        regex = '^[a-zA-Z0-9_\-/]+$'  # noqa: W605
+        regex = "^[a-zA-Z0-9_\.\-/]+$"  # noqa: W605
 
         if re.match(regex, alias) is None:
             alias = slugify(self.navYaml["site_name"])
@@ -284,7 +312,8 @@ class IncludeNavLoader:
 
                 if value.startswith(INCLUDE_STATEMENT):
                     log.critical(
-                        "[mkdocs-monorepo] We currently do not support nested !include statements inside of Mkdocs.")
+                        "[mkdocs-monorepo] We currently do not support nested !include statements inside of Mkdocs."
+                    )
                     raise SystemExit(1)
 
                 def formatNavLink(alias, value):
